@@ -1,6 +1,10 @@
 from django.conf.urls import url
 
-from apps.notebooks.views import ListNotebooks, RetrieveNotebook, RetrieveNotebookWithSlug
+from apps.notebooks.views import (
+    ListNotebooks,
+    RetrieveNotebook,
+    RetrieveNotebookWithSlug,
+)
 
 notebooks_urlpatterns = [
     url("api/v1/notebooks/(?P<notebook_id>.+)", RetrieveNotebook.as_view()),
